@@ -18,6 +18,7 @@ class run(object):
                  p_value_cutoff=0.05,
                  min_delta=0.05,
                  Majiq_confidence=0.95,
+                 only_DDIs=False
                 
                 ):
         
@@ -40,17 +41,19 @@ class run(object):
             
             input_type: str, optional
                 
-                Either "Standard" or "MAJIQ", If you need support of more types of outputs. Please contact: louadi@wzw.tum.de
+                Either "Standard","Spycone",'Whippet','rmats','spladder' or "MAJIQ", If you need support of more types of outputs. Please contact: louadi@wzw.tum.de
                 
             p_value_cutoff: float, optional
                The p value cutoff used to compute NEASE scores. (default is 0.05)
             
             min_delta: float, optional
-                min delta to consider in case your input has dPsi column  (default is 0.05)
+                min delta to consider in case your input has dPsi column. The value also corresponds  to logfold change in case of Dexeq.   (default is 0.05)
             
             Majiq_confidence: float, optional
                 In case of input_type='MAJIQ'. the parameter P(dPSI > 20%) is needed. Check MAJIQ paper for details about this  (default is 0.95)  
                 
+            only_DDIs: boolean, optional, default: False
+               if True only use DDI and exclude PDB and linear motif interactions
             
                 
          """
@@ -61,8 +64,9 @@ class run(object):
             print('Error: Please choose one of the  supported  organism: "Human" and "Mouse".')
         
          
-        if input_type!='MAJIQ' and input_type!='Standard':
+        if input_type!='MAJIQ' and input_type!='Standard' and input_type!='Spycone' and input_type!='Whippet' and input_type!='rmats' and input_type!='Dexeq':
             raise ValueError('Input type not supported')
+            
         else:
         
             # TO DO
@@ -72,14 +76,25 @@ class run(object):
             self.mapping=database_mapping[organism]
             self.path=Pathways[organism]
             self.ppi=PPI[organism]
+            self.only_DDIs=only_DDIs
+            self.elm_interactions=elm_interactions[organism]
+
+            if not only_DDIs:
+                
+                self.elm=elm[organism]
+                self.elm_interactions=elm_interactions[organism]
+                self.pdb=pdb[organism]
+            
             
             self.data=[]
             self.spliced_genes=[]
+            
+            
+            
             if input_type=='MAJIQ':
 
                 # Processing Majiq output
-                
-                        self.data,self.spliced_genes=process_MAJIQ(data,self.mapping, Majiq_confidence, min_delta )
+                        self.data,self.spliced_genes,self.elm_affected,self.pdb_affected=process_MAJIQ(data,self.mapping, Majiq_confidence, min_delta ,self.only_DDIs,self)
                         if len(self.data)==0:
                             print('Found no overlap with protein domains.')
 
@@ -88,48 +103,142 @@ class run(object):
             
             elif input_type=='Standard':
                     
-                #try:
-                    self.data,self.spliced_genes=process_standard(data,self.mapping,min_delta )
+                try:
+                    self.data,self.spliced_genes,self.elm_affected,self.pdb_affected=process_standard(data,self.mapping,min_delta ,self.only_DDIs,self)
                     if len(self.data)==0:
                         print('Found no overlap with protein domains.')
                         print('Make sure that the genomic coordinates of the exons correspond to the human genome build hg38 (GRCh38).')
 
                     
-                #except:
-                        #print('Could not recognize the standard format. Please make sure your table matches the standard format.')
-                        #print('Gene ensembl ID          EXON START        EXON END          dPSI (optional)')
-                        #print('Make sure that the genomic coordinates of the exons correspond to the human genome build hg38 (GRCh38).')
+                except:
+                        print('Could not recognize the standard format. Please make sure your table matches the standard format.')
+                        print('Gene ensembl ID          EXON START        EXON END          dPSI (optional)')
+                        print('Make sure that the genomic coordinates of the exons correspond to the human genome build hg38 (GRCh38).')
+                    
+            elif input_type=='Whippet':
+                
+                try:
+                
+                    data=data.rename_axis('Gene ID').reset_index()
+                    data['tmp']= data['Node'].apply(lambda x: x.split(':')[1])
+
+                    data['start']=data['tmp'].apply(lambda x: x.split('-')[0])
+                    data['end']=data['tmp'].apply(lambda x: x.split('-')[1])
+                    data=data[['Gene ID' , 'start','end','DeltaPsi']]
+
+                    self.data,self.spliced_genes,self.elm_affected,self.pdb_affected=process_standard(data,self.mapping,min_delta ,self.only_DDIs,self)
+                    
+                except:
+                        print('process failed....Try to use the Standard input')
+                
+                
+            elif input_type=='rmats':  
+                
+                try:
+                    
+                            data=data[data['FDR']<=p_value_cutoff]
+                            data=data[['GeneID','exonStart_0base','exonEnd','IncLevelDifference']]
+                            
+
+                            self.data,self.spliced_genes,self.elm_affected,self.pdb_affected=process_standard(data,self.mapping,min_delta ,self.only_DDIs,self)
+
+                except:
+                        print('process failed....Try to use the Standard input')
+                        
+                        
+            elif input_type=='Dexeq':  
+                
+                try:
+                            
+                            data=data[data['padj']<=p_value_cutoff]
+                            data=data[[data.columns[0],'genomicData.start','genomicData.end','log2fold_control_case']]
+                            print('proceding with log2fold threshold: '+str(min_delta))
+                            self.data,self.spliced_genes,self.elm_affected,self.pdb_affected=process_standard(data,self.mapping,min_delta ,self.only_DDIs,self)
+
+                except:
+                        print('process failed....Try to use the Standard input')
+            
+            elif input_type=='Spycone':
+                    
+                    self.data,self.spliced_genes=process_spycone(data,self.mapping)
+                    
+                    
+                    
+                    #spycone only uses DDI for now
+                    self.only_DDIs=True
+                    
+                    if len(self.data)==0:
+                        print('Found no overlap with protein domains.')
+                        
+  
                     
             
-            
-        
 
             
 
             if len(self.data)==0:
                 print('process canceled...')
+                
+                
+                
 
 
             else : 
                 self.data=self.data.drop_duplicates(['Gene name','NCBI gene ID','Gene stable ID','Pfam ID'],keep= 'first')
+                
+                
+                
                 # check interaction of the domains
-                self.data=exons_to_edges(self.data,Join)
+                 # prepare elm to doamin interactions file
+                self.elm_interactions['interactor 1']=self.elm_interactions['Interator gene 1'].astype('str')+"/"+self.elm_interactions['Elm id of gene 1']
+                self.elm_interactions['interactor 2']=self.elm_interactions['Interator gene 2'].astype('str')+"/"+self.elm_interactions['Domain of gene 2']
+                
+                self.data=exons_to_edges(self.data,Join,self.elm_interactions)
+                
+                
+                
                 print('\n\t\tData Summary')
                 print('**************************************************')
 
-                print(str(len(self.data['Domain ID'].unique()))+' protein domains are affected by AS.\n'
-                      + str(len(self.data[self.data['Interacting domain']]['Domain ID'].unique()))+' of the affected domains have known interactions.' ) 
+                print(str(len(self.data['Domain ID'].unique()))+' protein domains are affected by AS.\n')
+                if not self.only_DDIs:
+                    print(str(len(self.elm_affected['ELMIdentifier'].unique()))+" linear motifs are affected by AS.\n"
+                          +str(len(self.pdb_affected))+ ' interacting resiude are affected by AS.\n')
+                      
+                print(str(len(self.data[self.data['Interacting domain']]['Domain ID'].unique()))+' of the affected domains/motifs have known interactions.') 
+                
+                
+                
 
 
+               
+                
+                
+              
+                
+                
                 # Identify binding of affected domains = Edges in the PPI
-                self.interacting_domains=affected_edges(self.data,Join,self.mapping)
+                # get DMI adn DDI for spliced domains
+
+                self.interacting_domains=affected_edges(self,Join,self.only_DDIs)
+            
+                             
 
 
-
-                #get all edges of a gene
-                self.g2edges=gene_to_edges(self.interacting_domains)
+                #get all edges of a gene from DDIs
+                # self.interacting_domains,: DMI and DDI
+                # self.pdb_affected: co-resolved interactions
+                self.g2edges=gene_to_edges(self.interacting_domains,self.pdb_affected,self.only_DDIs)
                 
                 print(str(len([item for sublist in self.g2edges.values() for item in sublist]))+' protein interactions/binding affected.')
+                
+                
+                #get affected edges from ELM and PDB
+                
+                
+                
+                
+                
 
                 
                 # Runing Enrichment analysis
@@ -138,7 +247,7 @@ class run(object):
                 print('Running enrichment analysis...')
                 
                 self.supported_database=  list(self.path['source'].unique())
-                self.enrichment=pathway_enrichment(self.g2edges,self.path, self.mapping,organism,p_value_cutoff).reset_index(drop=True)
+                self.enrichment=pathway_enrichment(self.g2edges,self.path, self.mapping,organism,p_value_cutoff,self.only_DDIs).reset_index(drop=True)
                 print('NEASE enrichment done.')
                 
                 
@@ -159,19 +268,53 @@ class run(object):
             print('Processing failed')
         
         else:
+            
+            # initial number of genes with known affected features
+            
+            affecting_number=0
+            self.spliced_genes=list(set(self.spliced_genes))    
 
+            
             # number of genes with affected domains/number of all events (genes)
-            gene_number=len(self.data['NCBI gene ID'].unique())
-            affecting_percentage= round(gene_number/len(self.spliced_genes), 2)
-            interacting=len(self.data[self.data['Interacting domain']]['Domain ID'].unique())
+            genes_with_domain=self.data['Gene stable ID'].unique()
+            domain_number=len(genes_with_domain)
+            
+            
+            affecting_number=domain_number
+            number_of_features=domain_number
+            
+            if not self.only_DDIs:
+              
+                    # genes with affected elm
+                    genes_with_elm=list(self.elm_affected['Gene stable ID'].unique())
+                    
+                    # number of genes with elm affected
+                    elm_number=len(genes_with_elm)
+                    
+                    
+                    
+                    
+                    # number of genes with affected pdb
+                    genes_with_pdb=list(self.pdb_affected['Gene stable ID'].unique())
+                    pdb_number=len(genes_with_pdb)
+                    
+                    
+                    
+                    affecting_number=len(list(set(list(genes_with_elm)+list(genes_with_pdb)+list(genes_with_domain))))
+                    
+                    number_of_features=number_of_features+elm_number+pdb_number
+            
+      
 
-            domain_number=len(self.data['Domain ID'].unique())
-            binding_percentage=round(interacting/domain_number , 2)
+
+                    
+
+            affecting_percentage= round(affecting_number/len(self.spliced_genes), 2)
 
 
 
-
-            stats_domains(affecting_percentage,binding_percentage,file_path)
+            
+            stats_domains(affecting_percentage,number_of_features,domain_number,elm_number,pdb_number,file_path)
         return
         
         
@@ -180,7 +323,7 @@ class run(object):
     def get_domains(self):
         
         """
-            Display the list of AS events in NEASE format.
+            Display the list of AS events affectting domains in NEASE format.
             
         Returns
         -------
@@ -198,12 +341,71 @@ class run(object):
         else:
             
             #DIGGER visualization available for Human
-            return self.data.drop(columns=[ 'Domain ID'])
-    
+            return self.data.drop(columns=[ 'Domain ID','DDI','elm'])
     
     
     
     
+    def get_elm(self):
+        
+        """
+            Display list of linear motifs affected by AS.
+            
+        Returns
+        -------
+        pd.DataFrame Object
+        
+        """
+        
+        if self.only_DDIs:
+            print('You ran NEASE with the option:  only_DDIs=True. No ELM data available.')
+            
+        elif self.elm_affected.empty:
+            
+            print('No known linear motif are affected by AS')
+            
+        else:
+            self.elm_affected['ELM link']='http://elm.eu.org/elms/'+self.elm_affected.ELMIdentifier.astype('str')
+            
+            return self.elm_affected.drop(columns=[ 'ID','Affected binding (NCBI)'])
+           
+        
+    def get_pdb(self):
+        
+        """
+            Display list of linear motifs affected by AS.
+            
+        Returns
+        -------
+        pd.DataFrame Object
+        
+        """
+        if self.only_DDIs:
+            print('You ran NEASE with the option: only_DDIs=True. No pdb data available.')
+     
+        elif self.pdb_affected.empty:
+            
+            print('No residue from the PDB database motif are affected by AS')
+            
+        else:
+            pdb_affected=self.pdb_affected.rename(columns={"symbol": "Gene name",'entrezgene':'Co-resolved interactions'}).copy()
+            
+            #Convert IDs to names
+            c=lambda x: [ Entrez_to_name(gene,self.mapping) for gene in list(set(x))]
+            pdb_affected['Co-resolved interactions symbol']=pdb_affected['Co-resolved interactions'].apply(c)
+            
+            
+            
+            a=lambda x: ",".join(x)
+            pdb_affected['Co-resolved interactions']=pdb_affected['Co-resolved interactions'].apply(a)
+            pdb_affected['Co-resolved interactions symbol']=pdb_affected['Co-resolved interactions symbol'].apply(a)
+            
+            return pdb_affected[['Gene name','NCBI gene ID','Gene stable ID','Co-resolved interactions symbol','Co-resolved interactions']]
+        
+        
+        
+        
+            
     def get_edges(self):
         
         """   
@@ -219,14 +421,27 @@ class run(object):
         elif len(self.interacting_domains)==0:
             print('No affected edges identified.')
         else:
-            edges=self.interacting_domains[['Gene name','NCBI gene ID','dPSI','Pfam ID','Number of affected interactions','Affected binding','Affected binding (NCBI)']]
+            
+            
+            edges=self.interacting_domains.copy()
+            #Convert IDs to names
+            c=lambda x: [ Entrez_to_name(gene,self.mapping) for gene in list(set(x))]
+            edges['Affected binding']=edges['Affected binding (NCBI)'].apply(c)
+
+            # count number of affected PPI for every domain
+            count=lambda x: len(x)
+            edges['Number of affected interactions']=edges['Affected binding'].apply(count)
+            
+            
             a=lambda x: ",".join(x)
             edges['Affected binding']=edges['Affected binding'].apply(a)
             edges['Affected binding (NCBI)']=edges['Affected binding (NCBI)'].apply(a)
             edges=edges.drop_duplicates()
             edges=edges.sort_values('Number of affected interactions', ascending=False)
 
-            return edges.reset_index(drop=True)
+            return edges[['Gene name','NCBI gene ID','Identifier','dPSI','Number of affected interactions','Affected binding','Affected binding (NCBI)']].reset_index(drop=True)
+        
+        
     
           
     
@@ -339,8 +554,8 @@ class run(object):
                 
                 # Correct for multiple testing
                 # fdr_bh : Benjamini/Hochberg (non-negative)
-                #enrich_results['adj p_value']=sm.stats.multipletests(list(enrich_results['p_value']),method='fdr_bh',alpha=0.01)[1]
-                enrich_results['adj p_value']=sm.stats.fdrcorrection(list(enrich_results['p_value']),alpha=0.01)[1]
+                enrich_results['adj p_value']=sm.stats.multipletests(list(enrich_results['p_value']),method='fdr_bh',alpha=0.05)[1]
+                #enrich_results['adj p_value']=sm.stats.fdrcorrection(list(enrich_results['p_value']),alpha=0.01)[1]
                 
                 # shift column 'score to the last position
                 scores = enrich_results.pop('Nease score')
@@ -404,7 +619,7 @@ class run(object):
             print('Overall p_value: ',list(path_info['p_value'])[0])
             print('\n')
             # run enrichment
-            enrich,_=single_path_enrich(path_id,self.path,self.g2edges,self.mapping,self.organism)
+            enrich,_=single_path_enrich(path_id,self.path,self.g2edges,self.mapping,self.organism,self.only_DDIs)
             
             if len(enrich)==0:
                 print('No enrichment or genes found for the selected pathway.')
@@ -483,7 +698,7 @@ class run(object):
                 print('\n')
                 # run enrichment
 
-                enrich,affected_graph=single_path_enrich(path_id,self.path,self.g2edges,self.mapping,self.organism)
+                enrich,affected_graph=single_path_enrich(path_id,self.path,self.g2edges,self.mapping,self.organism,self.only_DDIs)
 
                 if len(enrich)==0:
                     print('No enrichment or genes found for the selected pathway.')
